@@ -4,7 +4,7 @@ from click import Context
 from typer import Typer, Option, Argument
 from typer.core import TyperGroup
 from typing import List
-from rich import print
+from rich import print as rprint
 from betanegbinfit import __version__ as bnb_version
 from jax import __version__ as jax_version
 from rich.progress import Progress, SpinnerColumn, TextColumn
@@ -22,6 +22,7 @@ import json
 from . import plot
 import os
 
+
 __all__ = ['main']
 
 class Compression(str, Enum):
@@ -55,7 +56,7 @@ class Allele(str, Enum):
 class Prior(str, Enum):
     laplace = 'laplace'
     normal = 'normal'
-
+    
 
 
 class OrderCommands(TyperGroup):
@@ -84,7 +85,7 @@ def update_history(name: str, command: str, **kwargs):
             if k.startswith('export'):
                 del d[k]
     elif command == 'test':
-        for k in ('test', 'export', 'export pvalues', 'export raw_pvalues'):
+        for k in ('test', 'combine', 'export', 'export pvalues', 'export raw_pvalues'):
             if k in d:
                 del d[k]
     elif command == 'combine':
@@ -106,29 +107,35 @@ def update_history(name: str, command: str, **kwargs):
     with open(f'{name}.json', 'w') as f:
         json.dump(d, f, indent=4)
 
-def reproduce(filename: str):
+def reproduce(filename: str, pretty: bool = True):
     with open(filename, 'r') as f:
         d = json.load(f)
     name = d['name']
     if d['betanegbinfit'] != bnb_version:
-        print(f'[yellow]Warning:[/yellow] Current [bold]betanegbinfit[/bold] version is {bnb_version}, but the project was created with'
+        rprint(f'[yellow]Warning:[/yellow] Current [bold]betanegbinfit[/bold] version is {bnb_version}, but the project was created with'
               f' {d["betanegbinfit"]}.')
     if d['jax'] != jax_version:
-        print(f'[yellow]Warning:[/yellow] Current [bold]JAX[/bold] version is {jax_version}, but the project was created with'
+        rprint(f'[yellow]Warning:[/yellow] Current [bold]JAX[/bold] version is {jax_version}, but the project was created with'
               f' {d["jax"]}.')
     if d['mixalime'] != mixalime_version:
-        print(f'[yellow]Warning:[/yellow] Current [bold]MixALime[/bold] version is {mixalime_version}, but the project was created with'
+        rprint(f'[yellow]Warning:[/yellow] Current [bold]MixALime[/bold] version is {mixalime_version}, but the project was created with'
               f' {d["mixalime"]}.')
     if d['dill'] != dill_version:
-        print(f'[yellow]Warning:[/yellow] Current [bold]dill[/bold] version is {dill_version}, but the project was created with'
+        rprint(f'[yellow]Warning:[/yellow] Current [bold]dill[/bold] version is {dill_version}, but the project was created with'
               f' {d["dill"]}.')
     for command, args in d.items():
+        if type(args) is str:
+            continue
+        r_old = args.get('expected_result', None)
+        if r_old is not None:
+            del args['expected_result']
+        args['pretty'] = pretty
         if command == 'create':
-            _create(name, **args)
+            r = _create(name, **args)
         elif command == 'fit':
-            _fit(name, **args)
+            r = _fit(name, **args)
         elif command == 'test':
-            _test(name, **args)
+            r = _test(name, **args)
         elif command.startswith('combine'):
             lt = command.split()
             if len(lt) != 1:
@@ -136,9 +143,9 @@ def reproduce(filename: str):
                 args['subname'] = subname
             if 'subname' in args:
                 del args['subname']
-            _combine(name, **args)
+            r = _combine(name, **args)
         elif command == 'plot':
-            _plot_all(name, **args)
+            r = _plot_all(name, **args)
         elif command.startswith('export'):
             lt = command.split()
             if len(lt) != 1:
@@ -152,7 +159,9 @@ def reproduce(filename: str):
                 elif what == 'indices':
                     _indices(name, **args)
             else:
-                _export_all(name, **args)
+                r = _export_all(name, **args)
+        if r_old and r != r_old:
+            raise Exception(f'"{name}" produced different result from what was recorded at the history file.')
     os.remove(f'{name}.json')
     if f'{name}.json' == filename:
         with open(filename, 'w') as f:
@@ -217,32 +226,51 @@ def _create(name: str = Argument(..., help='Project name. [bold]MixALime[/bold]
             filter_rs: bool = Option(False, help='Omit SNVs whose IDs don''t start with "[bold]rs[/bold]".'),
             filter_name: str = Option(None, help='Custom regex-compatible pattern: SNVs whose IDs are not in an agreement with the pattern, '
                                                   'shall be omitted.'), 
-            compression: Compression = Option(Compression.lzma.value, help='Compression method used to store results.')):
+            filter_chr: str = Option(None, help='Custom regex-compatible pattern for chr filtering. Possible applicaitons include omitting scaffold '
+                                                'data.'),
+            compression: Compression = Option(Compression.lzma.value, help='Compression method used to store results.'), 
+            pretty: bool = Option(True, help='Use "rich" package to produce eye-candy output.')):
     if cnt_max_sum is None:
         cnt_max_sum = float('inf')
     files = list(map(str, files))
     if bad_maps:
         bad_maps = str(bad_maps)
     t0 = time()
+    if not pretty:
+        print('Processing files...')
     _, samples, snvs = create_project(name=name, snvs=files, bad_maps=bad_maps, default_bad=default_bad, drop_bads=drop_bad, min_qual=min_qual,
                                       min_cnt=min_cnt, cnt_max_sum=cnt_max_sum, filter_db=filter_db, filter_rs=filter_rs, symmetrify=symmetrify,
-                                      filter_name=filter_name, compression=compression, count_snvs=True)
-    table = Table('BAD', 'SNVs', 'Samples/reps')
+                                      filter_name=filter_name, filter_chr=filter_chr, compression=compression, count_snvs=True, 
+                                      progress_bar=pretty)
+    rows = list()
     tot_snv = 0
     tot_samples = 0
     for bad in sorted(samples):
         a = len(snvs[bad])
         b = samples[bad]
-        table.add_row('{:.2f}'.format(bad), str(a), str(b))
+        rows.append(['{:.2f}'.format(bad), str(a), str(b)])
         tot_snv += a
         tot_samples += b
-    print(table)
-    print(f'Total SNVs: {tot_snv}, total samples/reps: {tot_samples}')
+    rows = rows
+    if pretty:
+        table = Table('BAD', 'SNVs', 'Samples/reps')
+        for row in rows:
+            table.add_row(*row)
+        rprint(table)
+        rprint(f'Total SNVs: {tot_snv}, total samples/reps: {tot_samples}')
+    else:
+        print('BAD\tSNVs\tSamples/reps')
+        print('\n'.join(['\t'.join(row) for row in rows]))     
+        print(f'Total SNVs: {tot_snv}, total samples/reps: {tot_samples}')    
     update_history(name, 'create', files=files, bad_maps=bad_maps, default_bad=default_bad, drop_bad=drop_bad, min_qual=min_qual,
                    min_cnt=min_cnt, cnt_max_sum=cnt_max_sum, filter_db=filter_db, filter_rs=filter_rs, symmetrify=symmetrify,
-                   filter_name=filter_name, compression=compression)
+                   filter_name=filter_name, filter_chr=filter_chr, compression=compression, expected_result=rows)
     dt = time() - t0
-    print(f'[green][bold]✔️[/bold] Done![/green]\t time: {dt:.2f} s.')
+    if pretty:
+        rprint(f'[green][bold]✔️[/bold] Done![/green]\t time: {dt:.2f} s.')
+    else:
+        print(f'✔️ Done!\t time: {dt:.2f} s.')
+    return rows
 
 @app.command('fit')
 def _fit(name: str = Argument(..., help='Project name.'),
@@ -258,7 +286,7 @@ def _fit(name: str = Argument(..., help='Project name.'),
                                                                                   'met).'),
          min_slices: int = Option(1, help='Minimal number of slices per window.'),
          adjust_line: bool = Option(False, help='Line parameter beta and mu will be reestimated without a loss of likelihood so they differ'
-                                                ' as little as possible from  the previous b and mu estimates.'),
+                                                ' as little as possible from the previous b and mu estimates.'),
          k_left_bound: int = Option(1, help='Minimal allowed value for concentration parameter [italic]k[/italic].'),
          max_count: int = Option(None, help='Maximal number of counts for an allele (be it ref or alt).'),
          max_cover: int = Option(None, help='Maximal sum of ref + alt.'), 
@@ -271,7 +299,8 @@ def _fit(name: str = Argument(..., help='Project name.'),
          regul_prior: Prior = Option('laplace', help='Prior distribution used to penalize concentration parameter kappa. Valid only for '
                                                      '[cyan]model[/cyan]=[yellow]window[/yellow].'),
          adjusted_loglik: bool = Option(False, help='Calculate adjusted loglikelihood alongside other statistics.'),
-         n_jobs: int = Option(-1, help='Number of jobs to be run at parallel, -1 will use all available threads.')):
+         n_jobs: int = Option(-1, help='Number of jobs to be run at parallel, -1 will use all available threads.'),
+         pretty: bool = Option(True, help='Use "rich" package to produce eye-candy output.')):
     """
     Fit a a mixture model parameters to data for the given project.
     """
@@ -291,18 +320,27 @@ def _fit(name: str = Argument(..., help='Project name.'),
     if type(regul_prior) is Prior:
         regul_prior = regul_prior.value
     t0 = time()
-    with Progress(SpinnerColumn(speed=0.5), TextColumn("[progress.description]{task.description}"), transient=True) as p:
+    if pretty:
+        p = Progress(SpinnerColumn(speed=0.5), TextColumn("[progress.description]{task.description}"), transient=True)
         p.add_task(description="Optimizing model parameters...", total=None)
-        fit(name, dist=dist, model=model, left=left, estimate_p=estimate_p, window_size=window_size, 
-            window_behavior=window_behavior, min_slices=min_slices, adjust_line=adjust_line, k_left_bound=k_left_bound,
-            max_count=max_count, max_cover=max_cover, adjusted_loglik=adjusted_loglik, n_jobs=n_jobs, start_est=start_est,
-            apply_weights=apply_weights, regul_alpha=regul_alpha, regul_n=regul_n, regul_slice=regul_slice, regul_prior=regul_prior)
+        p.start()
+    else:
+        print('Optimizing model parameters...')
+    fit(name, dist=dist, model=model, left=left, estimate_p=estimate_p, window_size=window_size, 
+        window_behavior=window_behavior, min_slices=min_slices, adjust_line=adjust_line, k_left_bound=k_left_bound,
+        max_count=max_count, max_cover=max_cover, adjusted_loglik=adjusted_loglik, n_jobs=n_jobs, start_est=start_est,
+        apply_weights=apply_weights, regul_alpha=regul_alpha, regul_n=regul_n, regul_slice=regul_slice, regul_prior=regul_prior)
+    if pretty:
+        p.stop()
     update_history(name, 'fit', dist=dist, model=model, left=left, estimate_p=estimate_p, window_size=window_size, 
                    window_behavior=window_behavior, min_slices=min_slices, adjust_line=adjust_line, k_left_bound=k_left_bound,
                    max_count=max_count, max_cover=max_cover, adjusted_loglik=adjusted_loglik, n_jobs=n_jobs, 
                    regul_alpha=regul_alpha, regul_n=regul_n, regul_slice=regul_slice, regul_prior=regul_prior)
     dt = time() - t0
-    print(f'[green][bold]✔️[/bold] Done![/green]\t time: {dt:.2f} s.')
+    if pretty:
+        rprint(f'[green][bold]✔️[/bold] Done![/green]\t time: {dt:.2f} s.')
+    else:
+        print(f'✔️ Done!\t time: {dt:.2f} s.')
 
 @app.command('test')
 def _test(name: str = Argument(..., help='Project name.'),
@@ -311,19 +349,30 @@ def _test(name: str = Argument(..., help='Project name.'),
                                                                       ' an impact of more distant component.'),
           gof_tr: float = Option(None, help='Conservative scoring will be used if goodness-of-fit statistic (RMSEA) exceeds [cyan]gof-tr[/cyan] '
                                             'for a particular slice.'),
-          n_jobs: int = Option(-1, help='Number of jobs to be run at parallel, -1 will use all available threads.')):
+          n_jobs: int = Option(1, help='Number of jobs to be run at parallel, -1 will use all available threads.'),
+          pretty: bool = Option(True, help='Use "rich" package to produce eye-candy output.')):
     """
     Calculate p-values using parameter estimates obtained after [cyan bold]fit[/cyan bold] command.
     """
     if type(correction) is Correction:
         correction = correction.value
     t0 = time()
-    with Progress(SpinnerColumn(speed=0.5), TextColumn("[progress.description]{task.description}"), transient=True) as p:
+    if pretty:
+        p = Progress(SpinnerColumn(speed=0.5), TextColumn("[progress.description]{task.description}"), transient=True)
         p.add_task(description="Comptuing p-values and effect sizes...", total=None)
-        test(name, correction=correction, gof_tr=gof_tr, n_jobs=n_jobs)
+        p.start()
+    else:
+        print('Computing p-values and effect sizes...')
+    test(name, correction=correction, gof_tr=gof_tr, n_jobs=n_jobs)
+    if pretty:
+        p.stop()
     update_history(name, 'test', correction=correction, gof_tr=gof_tr, n_jobs=n_jobs)
     dt = time() - t0
-    print(f'[green][bold]✔️[/bold] Done![/green]\t time: {dt:.2f} s.')
+    if pretty:
+        rprint(f'[green][bold]✔️[/bold] Done![/green]\t time: {dt:.2f} s.')
+    else:
+        print(f'✔️ Done!\t time: {dt:.2f} s.')
+        
 
 @app.command('combine')
 def _combine(name: str = Argument(..., help='Project name.'),
@@ -331,18 +380,26 @@ def _combine(name: str = Argument(..., help='Project name.'),
                                                                       'those filenames or file(s) that contain a list of paths to files.'
                                                                       ' SNV p-values from those files shall be combined via logit method.'),
              alpha: float = Option(0.05, help='FWER, family-wise error rate.'),
-             id_startswith: str = Option(None, help='Only SNVs whose IDs start with this strings are tested (e.g. "rs").'),
+             filter_id: str = Option(None, help='Only SNVs whose IDs agree with this regex pattern are tested (e.g. "rs\w+").'),
+             filter_chr: str = Option(None, help='SNVs with chr that does not align with this regex pattern are filtered (e.g. "chr\d+").'),
              subname: str = Option(None, help='You may give a result a subname in case you plan to use multiple groups.'),
-             n_jobs: int = Option(-1, help='Number of jobs to be run at parallel, -1 will use all available threads.')):
+             n_jobs: int = Option(1, help='Number of jobs to be run at parallel, -1 will use all available threads.'),
+             pretty: bool = Option(True, help='Use "rich" package to produce eye-candy output.')):
     """
     Combine p-values obtained at [cyan bold]test[/cyan bold] stage with a Mudholkar-George method.
     """
     if group:
         group = list(map(str, group))
     t0 = time()
-    with Progress(SpinnerColumn(speed=0.5), TextColumn("[progress.description]{task.description}"), transient=True) as p:
+    if pretty:
+        p = Progress(SpinnerColumn(speed=0.5), TextColumn("[progress.description]{task.description}"), transient=True)
         p.add_task(description="Combining p-values with respect to sample groups...", total=None)
-        r = combine(name, group_files=group, alpha=alpha, id_startswith=id_startswith, subname=subname, n_jobs=n_jobs)[subname]
+        p.start()
+    else:
+        print('Combining p-values with respect to sample groups...')
+    r = combine(name, group_files=group, alpha=alpha, filter_id=filter_id, subname=subname, n_jobs=n_jobs)[subname]
+    if pretty:
+        p.stop()
     ref = alt = both = total = 0
     for t in r.values():
         pv_ref, pv_alt = t[-1]
@@ -350,39 +407,62 @@ def _combine(name: str = Argument(..., help='Project name.'),
         alt += pv_alt < alpha
         total += (pv_ref < alpha) | (pv_alt < alpha)
         both += (pv_ref < alpha) & (pv_alt < alpha)
-    print('Number of significant SNVs after FDR correction:')
-    table = Table('Ref', 'Alt', 'Both', 'Total significant\n(Percentage of total SNVs)')
-    table.add_row(str(ref), str(alt), str(both), f'{total} ({total/len(r) * 100:.2f}%)')
-    print(table)
-    update_history(name, 'combine', group=group, alpha=alpha, id_startswith=id_startswith, subname=subname, n_jobs=n_jobs)
+    expected_res = [int(ref), int(alt), int(both)]
+    if pretty:
+        rprint('Number of significant SNVs after FDR correction:')
+        table = Table('Ref', 'Alt', 'Both', 'Total significant\n(Percentage of total SNVs)')
+        table.add_row(str(ref), str(alt), str(both), f'{total} ({total/len(r) * 100:.2f}%)')
+        rprint(table)
+    else:
+        print('Number of significant SNVs after FDR correction:')
+        print('\t'.join(('Ref', 'Alt', 'Both', 'Total significant (Percentage of total SNVs)')))
+        print('\t'.join((str(ref), str(alt), str(both), f'{total} ({total/len(r) * 100:.2f}%)')))
+    update_history(name, 'combine', group=group, alpha=alpha, filter_id=filter_id, subname=subname, filter_chr=filter_chr, n_jobs=n_jobs,
+                   expected_result=expected_res)
     dt = time() - t0
-    print(f'[green][bold]✔️[/bold] Done![/green]\t time: {dt:.2f} s.')
+    if pretty:
+        rprint(f'[green][bold]✔️[/bold] Done![/green]\t time: {dt:.2f} s.')
+    else:
+        print(f'✔️ Done!\t time: {dt:.2f} s.')
+        
+    return expected_res
 
 
 @app_export.command('all', help='Export everything.')
 def _export_all(name: str = Argument(..., help='Project name.'), out: Path = Argument(..., help='Output filename/path.'),
                 rep_info: bool = Option(False, help='Include raw p-values and names of sample scorefiles to the tabular. '
-                                                    'Note that this may bloat output if number of samples is high.')):
+                                                    'Note that this may bloat output if number of samples is high.'),
+                pretty: bool = Option(True, help='Use "rich" package to produce eye-candy output.')):
     out = str(out)
     t0 = time()
-    with Progress(SpinnerColumn(speed=0.5), TextColumn("[progress.description]{task.description}"), transient=True) as p:
+    if pretty:
+        p = Progress(SpinnerColumn(speed=0.5), TextColumn("[progress.description]{task.description}"), transient=True)
         p.add_task(description="Exporting tabular data...", total=None)
-        export.export_all(name, out, rep_info=rep_info)
+        p.start()
+    export.export_all(name, out, rep_info=rep_info)
+    if pretty:
+        p.stop()
     update_history(name, 'export', out=out, rep_info=rep_info)
     dt = time() - t0
-    print(f'[green][bold]✔️[/bold] Done![/green]\t time: {dt:.2f} s.')
+    if pretty:
+        rprint(f'[green][bold]✔️[/bold] Done![/green]\t time: {dt:.2f} s.')
+    else:
+        print(f'✔️ Done!\t time: {dt:.2f} s.')
 
 @app_export.command('counts')
 def _counts(name: str = Argument(..., help='Project name.'), out: str = Argument(..., help='Output filename/path.'),
             bad: float = Option(None, help='If provided, then only this particular BAD will be exported. In that case, [cyan]out[/cyan] is a '
                                            'filename, not a name of directory. Otherwise, counts from all bads will be exported to the'
-                                           ' [cyan]out[/cyan] path.'
-                                        )):
+                                           ' [cyan]out[/cyan] path.'),
+            pretty: bool = Option(True, help='Use "rich" package to produce eye-candy output.')):
     """
     Export counts data.
     """
     export.export_counts(name, out, bad=bad)
-    print('[green][bold]✔️[/bold] Done![/green]')
+    if pretty:
+        rprint('[green][bold]✔️[/bold] Done![/green]')
+    else:
+        print('✔️ Done!')
 
 @app_export.command('params')
 def _params(name: str = Argument(..., help='Project name.'), out: str = Argument(..., help='Output filename/path.'),
@@ -390,7 +470,8 @@ def _params(name: str = Argument(..., help='Project name.'), out: str = Argument
                                            'filename, not a name of directory. Otherwise, params obtained from all BADs will be exported to the'
                                            ' [cyan]out[/cyan] path.'),
             allele: Allele = Option(None, help='Allele name (remember that we fit 2 separate models with respect to [yellow]ref[/yellow]'
-                                               ' and [yellow]alt[/yellow] alleles). Must be provided as well if [cyan]bad[/cyan] is provided.')):
+                                               ' and [yellow]alt[/yellow] alleles). Must be provided as well if [cyan]bad[/cyan] is provided.'),
+            pretty: bool = Option(True, help='Use "rich" package to produce eye-candy output.')):
     """
     Export parameters estimates.
     """
@@ -398,7 +479,10 @@ def _params(name: str = Argument(..., help='Project name.'), out: str = Argument
         allele = allele.value
     export.export_params(name, out, bad=bad, allele=allele)
     update_history(name, 'export params', out=out, bad=bad, allele=allele)
-    print('[green][bold]✔️[/bold] Done![/green]')
+    if pretty:
+        rprint('[green][bold]✔️[/bold] Done![/green]')
+    else:
+        print('✔️ Done!')
 
 @app_export.command('indices')
 def _indices(name: str = Argument(..., help='Project name.'), out: Path = Argument(..., help='Output filename/path.'),
@@ -406,7 +490,8 @@ def _indices(name: str = Argument(..., help='Project name.'), out: Path = Argume
                                             'filename, not a name of directory. Otherwise, indices obtained from all BADs will be exported to the'
                                             ' [cyan]out[/cyan] path.'),
              allele: Allele = Option(None, help='Allele name (remember that we fit 2 separate models with respect to [yellow]ref[/yellow]'
-                                                ' and [yellow]alt[/yellow] alleles). Must be provided as well if [cyan]bad[/cyan] is provided.')):
+                                                ' and [yellow]alt[/yellow] alleles). Must be provided as well if [cyan]bad[/cyan] is provided.'),
+             pretty: bool = Option(True, help='Use "rich" package to produce eye-candy output.')):
     """
     Export fit indices.
     """
@@ -415,7 +500,10 @@ def _indices(name: str = Argument(..., help='Project name.'), out: Path = Argume
         allele = allele.value
     export.export_stats(name, out, bad=bad, allele=allele)
     update_history(name, 'export indices', out=out, bad=bad, allele=allele)
-    print('[green][bold]✔️[/bold] Done![/green]')
+    if pretty:
+        rprint('[green][bold]✔️[/bold] Done![/green]')
+    else:
+        print('✔️ Done!')
 
 
 @app_export.command('pvalues')
@@ -423,34 +511,46 @@ def _combined_pvalues(name: str = Argument(..., help='Project name.'), out: Path
                       rep_info: bool = Option(False, help='Include raw p-values and names of sample scorefiles to the tabular. '
                                                           'Note that this may bloat output if number of samples is high.'),
                       subname: str = Option(None, help='A subname that can be used to reference a set of combined p-values in case if you'
-                                                       ' provided one at [cyan bold]combine[/cyan bold] step.')):
+                                                       ' provided one at [cyan bold]combine[/cyan bold] step.'),
+                      pretty: bool = Option(True, help='Use "rich" package to produce eye-candy output.')):
     '''
     Export combined across samples and FDR-corrected p-values.
     '''
     out = str(out)
     export.export_combined_pvalues(name, out, rep_info=rep_info, subname=subname)
     update_history(name, 'export pvalues', out=out, rep_info=rep_info, subname=subname)
-    print('[green][bold]✔️[/bold] Done![/green]')
+    if pretty:
+        rprint('[green][bold]✔️[/bold] Done![/green]')
+    else:
+        print('✔️ Done!')
 
 
 help_str = 'Export "raw" pvalues (i.e. prior to combining them across samples and FDR-corrections). '\
            'Note that for each vcf/BED-like file submitted at [cyan bold]create[/cyan bold] stage, this command will '\
            'spawn a tabular file with similar name (including a relative path).'
 @app_export.command('raw_pvalues', help=help_str)
-def _raw_pvalues(name: str, out: Path):
+def _raw_pvalues(name: str, out: Path,
+                 pretty: bool = Option(True, help='Use "rich" package to produce eye-candy output.')):
     out = str(out)
     export.export_pvalues(name, out)
     update_history(name, 'export raw-pvalues', out=out)
-    print('[green][bold]✔️[/bold] Done![/green]')
+    if pretty:
+        rprint('[green][bold]✔️[/bold] Done![/green]')
+    else:
+        print('✔️ Done!')
 
 @app_export.command('demo')
-def _demo(export_path: Path = Option(str(), help='Path where the demo data will be extracted.')):
+def _demo(export_path: Path = Option(str(), help='Path where the demo data will be extracted.'),
+          pretty: bool = Option(True, help='Use "rich" package to produce eye-candy output.')):
     '''
     Extract demonstration data from ChIP-seq experiment.
     '''
     export_path = str(export_path)
     export.export_demo(export_path)
-    print('[green][bold]✔️[/bold] Done![/green]')
+    if pretty:
+        rprint('[green][bold]✔️[/bold] Done![/green]')
+    else:
+        print('✔️ Done!')
     
 
 @app.command('plot', help='Visualize model fits and plot model fit indices for diagnostic purposes.')
@@ -460,20 +560,31 @@ def _plot_all(name: str = Argument(..., help='Project name.'), out: Path = Argum
               bad: float = Option(None, help='Draw plots only for this particular BAD.'),
               show_bad: bool = Option(True, help='Show BADs in figures'' titles.'),
               dpi: int = Option(200, help='DPI.'),
-              fmt: str = Option('png', help='Image format.')):
+              fmt: str = Option('png', help='Image format.'),
+              pretty: bool = Option(True, help='Use "rich" package to produce eye-candy output.')):
     out = str(out)
     t0 = time()
-    with Progress(SpinnerColumn(speed=0.5), TextColumn("[progress.description]{task.description}"), transient=True) as p:
+    if pretty:
+        p = Progress(SpinnerColumn(speed=0.5), TextColumn("[progress.description]{task.description}"), transient=True)
         p.add_task(description="Plotting figures...", total=None)
-        plot.visualize(name, out, what='all', max_count=max_count, slices=slices, fbad=bad, show_bad=show_bad, fmt=fmt, dpi=dpi)
+        p.start()
+    else:
+        print('Plotting figures...')
+    plot.visualize(name, out, what='all', max_count=max_count, slices=slices, fbad=bad, show_bad=show_bad, fmt=fmt, dpi=dpi)
+    if pretty:
+        p.stop()
     update_history(name, 'plot', out=out, max_count=max_count, slices=slices, bad=bad, show_bad=show_bad, fmt=fmt, dpi=dpi)
     dt = time() - t0
-    print(f'[green][bold]✔️[/bold] Done![/green]\t time: {dt:.2f} s.')
+    if pretty:
+        rprint(f'[green][bold]✔️[/bold] Done![/green]\t time: {dt:.2f} s.')
+    else:
+        print(f'✔️ Done!\t time: {dt:.2f} s.')
 
 @app.command('reproduce', help='Reproduce a project as was recorded by a history file.')
-def _reproduce(filename: Path = Argument(..., help='Path to the history JSON file.')):
+def _reproduce(filename: Path = Argument(..., help='Path to the history JSON file.'),
+               pretty: bool = Option(True, help='Use "rich" package to produce eye-candy output.')):
     filename = str(filename)
-    reproduce(filename)
+    reproduce(filename, pretty=pretty)
 
 def main():
     app()
